clear %Lschung des Arbeitsspeichers (workspace)

%Berechnung der Kraft-Lngen-Funktion
%Muskellngen, bei denen sich der Anstieg der Kraft-Lngen-Funktion ndert
L_1=-24e-3; %[mm]
L_2=-14e-3; %[mm]
L_3=4e-3; %[mm]
L_4=36e-3; %[mm]
F_iso=20.6; %isometrische Kraft [N]
Fc=0.51; %Kraft, bei der sich der Anstieg der Kraft-Lngen-Funktion im aufsteigenden Ast ndert [F_iso]
L_cc=L_1:5e-4:L_4;    %Vektor der Muskellnge[m]
F_length=NaN(1,length(L_cc));
for ii=1:length(L_cc)
    if L_cc(ii)>L_1 && L_cc(ii)<=L_2
        F_length(ii)=Fc/(L_2-L_1)*(L_cc(ii)-L_1);
    elseif L_cc(ii)>L_2 && L_cc(ii)<=0
        F_length(ii)=-(Fc-1)/(-L_2)*(L_cc(ii)-L_2)+Fc;
    elseif L_cc(ii)>0 && L_cc(ii)<=L_3
        F_length(ii)=1;
    elseif L_cc(ii)>L_3 && L_cc(ii)<=L_4
        F_length(ii)=-1/(L_4-L_3)*(L_cc(ii)-L_3)+1;
    end
end

%Berechnung der Kraft-Geschwindigkeits-Funktion
v_max=152e-3; %maximale Kontraktionsgeschwindigkeit (maximum voluntary contraction) des Muskels [m/s]
v_vec=-v_max:5e-3:v_max;
curv=9.5; %Krmmungsparameter der Kraft-Geschwindigkeitsfunktion
C=v_max/(4*(1+curv)); %Parameter abhngig vom Krmmungsparameter
B=2*C; %Parameter abhngig vom Krmmungsparameter
F_vel=NaN(length(v_vec),1);
for ii=1:length(v_vec)
    v_vec_ii=v_vec(ii);
    if v_vec_ii>0 %Kraft-Geschwindigkeits-Funktion fr v>0
        F_vel(ii)=(v_max-v_vec_ii)./(v_max+v_vec_ii*curv);
    else %Kraft-Lngen-Geschwindigkeits fr v<=0
        F_vel(ii)=C/(v_vec_ii-B)+1.5;
    end
end

Act=1; %Aktivierung zwischen 0 und 1
F_grid=Act*F_iso*F_vel*F_length; %Produktansatz Muskelkraft

%Erstellung des Graphen
surf(L_cc*1e3,v_vec/v_max,F_grid/F_iso)
xlabel('L_{cc} [mm]','FontSize',12) %Beschriftung x-Achse
ylabel('Geschwindigkeit [v_{max}]','FontSize',12) %Beschriftung y-Achse
zlabel('Kraft [F_{iso}]','FontSize',12) %Beschriftung z-Achse
title('Muskelkraft','FontSize',16) %Titel
%axis equal
view(160,44)
shg